@@ -1,6 +1,6 @@
 package Net::SFTP::Foreign::Constants;
 
-our $VERSION = '0.90_03';
+our $VERSION = '0.90_04';
 
 use strict;
 use warnings;
@@ -30,6 +30,8 @@ BEGIN {
 		      SSH2_FXP_REALPATH => 16,
 		      SSH2_FXP_STAT => 17,
 		      SSH2_FXP_RENAME => 18,
+		      SSH2_FXP_READLINK => 19,
+		      SSH2_FXP_SYMLINK => 20,
 		      SSH2_FXP_STATUS => 101,
 		      SSH2_FXP_HANDLE => 102,
 		      SSH2_FXP_DATA => 103,
@@ -89,7 +91,13 @@ BEGIN {
 		      SFTP_ERR_LOCAL_OPEN_FAILED => 26,
 		      SFTP_ERR_LOCAL_STAT_FAILED => 27,
 		      SFTP_ERR_LOCAL_READ_ERROR => 28,
-		      SFTP_ERR_REMOTE_READDIR_FAILED => 29 );
+		      SFTP_ERR_REMOTE_READDIR_FAILED => 29,
+		      SFTP_ERR_REMOTE_READLINK_FAILED => 30,
+		      SFTP_ERR_REMOTE_SYMLINK_FAILED => 31,
+		      SFTP_ERR_REMOTE_BAD_PATH => 32,
+		      SFTP_ERR_LOCAL_MKDIR_FAILED => 33,
+		      SFTP_ERR_LOCAL_SYMLINK_FAILED => 34,
+		      SFTP_ERR_REMOTE_BAD_OBJECT => 35 );
 
     for my $key (keys %constants) {
 	no strict 'refs';
@@ -186,6 +194,7 @@ C<SFTP_ERR_REMOTE_OPENDIR_FAILED>, C<SFTP_ERR_REMOTE_OPEN_FAILED>,
 C<SFTP_ERR_REMOTE_READDIR_FAILED>, C<SFTP_ERR_REMOTE_READ_FAILED>,
 C<SFTP_ERR_REMOTE_REALPATH_FAILED>, C<SFTP_ERR_REMOTE_REMOVE_FAILED>,
 C<SFTP_ERR_REMOTE_RENAME_FAILED>, C<SFTP_ERR_REMOTE_RMDIR_FAILED>,
+C<SFTP_ERR_REMOTE_READLINK_FAILED>, C<SFTP_ERR_REMOTE_SYMLINK_FAILED>,
 C<SFTP_ERR_REMOTE_SETSTAT_FAILED>, C<SFTP_ERR_REMOTE_STAT_FAILED> and
 C<SFTP_ERR_REMOTE_WRITE_FAILED>.
 
